@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.MigrationHubRefactorSpaces 1.24.16\nVersion:        "
-        " 1.24.16\nBuilder version: 7.7.1\nDocs:           "
+        "Type annotations for boto3.MigrationHubRefactorSpaces 1.24.36\nVersion:        "
+        " 1.24.36.post1\nBuilder version: 7.10.0\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migration_hub_refactor_spaces//\nBoto3"
         " docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migration-hub-refactor-spaces.html#MigrationHubRefactorSpaces\nOther"
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.24.16")
+    print("1.24.36.post1")
 
 
 def main() -> None:
