@@ -18,7 +18,7 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import RouteTypeType, ServiceEndpointTypeType
+from .literals import RouteActivationStateType, RouteTypeType, ServiceEndpointTypeType
 from .paginator import (
     ListApplicationsPaginator,
     ListEnvironmentsPaginator,
@@ -32,6 +32,7 @@ from .type_defs import (
     CreateEnvironmentResponseTypeDef,
     CreateRouteResponseTypeDef,
     CreateServiceResponseTypeDef,
+    DefaultRouteInputTypeDef,
     DeleteApplicationResponseTypeDef,
     DeleteEnvironmentResponseTypeDef,
     DeleteRouteResponseTypeDef,
@@ -48,6 +49,7 @@ from .type_defs import (
     ListRoutesResponseTypeDef,
     ListServicesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    UpdateRouteResponseTypeDef,
     UriPathRouteInputTypeDef,
     UrlEndpointInputTypeDef,
 )
@@ -106,6 +108,14 @@ class MigrationHubRefactorSpacesClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migration_hub_refactor_spaces/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migration-hub-refactor-spaces.html#MigrationHubRefactorSpaces.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migration_hub_refactor_spaces/client/#close)
+        """
+
     def create_application(
         self,
         *,
@@ -148,6 +158,7 @@ class MigrationHubRefactorSpacesClient(BaseClient):
         RouteType: RouteTypeType,
         ServiceIdentifier: str,
         ClientToken: str = ...,
+        DefaultRoute: DefaultRouteInputTypeDef = ...,
         Tags: Mapping[str, str] = ...,
         UriPathRoute: UriPathRouteInputTypeDef = ...
     ) -> CreateRouteResponseTypeDef:
@@ -383,6 +394,21 @@ class MigrationHubRefactorSpacesClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migration_hub_refactor_spaces/client/#untag_resource)
         """
 
+    def update_route(
+        self,
+        *,
+        ActivationState: RouteActivationStateType,
+        ApplicationIdentifier: str,
+        EnvironmentIdentifier: str,
+        RouteIdentifier: str
+    ) -> UpdateRouteResponseTypeDef:
+        """
+        Updates an Amazon Web Services Migration Hub Refactor Spaces route.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migration-hub-refactor-spaces.html#MigrationHubRefactorSpaces.Client.update_route)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migration_hub_refactor_spaces/client/#update_route)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_applications"]
