@@ -22,6 +22,7 @@ from .literals import (
     ErrorCodeType,
     ErrorResourceTypeType,
     HttpMethodType,
+    RouteActivationStateType,
     RouteStateType,
     RouteTypeType,
     ServiceEndpointTypeType,
@@ -45,6 +46,7 @@ __all__ = (
     "ErrorResponseTypeDef",
     "ResponseMetadataTypeDef",
     "CreateEnvironmentRequestRequestTypeDef",
+    "DefaultRouteInputTypeDef",
     "UriPathRouteInputTypeDef",
     "LambdaEndpointInputTypeDef",
     "UrlEndpointInputTypeDef",
@@ -73,6 +75,7 @@ __all__ = (
     "UrlEndpointSummaryTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateRouteRequestRequestTypeDef",
     "CreateApplicationRequestRequestTypeDef",
     "ApplicationSummaryTypeDef",
     "EnvironmentSummaryTypeDef",
@@ -88,6 +91,7 @@ __all__ = (
     "GetResourcePolicyResponseTypeDef",
     "GetRouteResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "UpdateRouteResponseTypeDef",
     "CreateRouteRequestRequestTypeDef",
     "CreateRouteResponseTypeDef",
     "CreateServiceRequestRequestTypeDef",
@@ -191,10 +195,18 @@ class CreateEnvironmentRequestRequestTypeDef(
     pass
 
 
+DefaultRouteInputTypeDef = TypedDict(
+    "DefaultRouteInputTypeDef",
+    {
+        "ActivationState": RouteActivationStateType,
+    },
+    total=False,
+)
+
 _RequiredUriPathRouteInputTypeDef = TypedDict(
     "_RequiredUriPathRouteInputTypeDef",
     {
-        "ActivationState": Literal["ACTIVE"],
+        "ActivationState": RouteActivationStateType,
         "SourcePath": str,
     },
 )
@@ -509,6 +521,16 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+UpdateRouteRequestRequestTypeDef = TypedDict(
+    "UpdateRouteRequestRequestTypeDef",
+    {
+        "ActivationState": RouteActivationStateType,
+        "ApplicationIdentifier": str,
+        "EnvironmentIdentifier": str,
+        "RouteIdentifier": str,
+    },
+)
+
 _RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateApplicationRequestRequestTypeDef",
     {
@@ -768,6 +790,19 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+UpdateRouteResponseTypeDef = TypedDict(
+    "UpdateRouteResponseTypeDef",
+    {
+        "ApplicationId": str,
+        "Arn": str,
+        "LastUpdatedTime": datetime,
+        "RouteId": str,
+        "ServiceId": str,
+        "State": RouteStateType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 _RequiredCreateRouteRequestRequestTypeDef = TypedDict(
     "_RequiredCreateRouteRequestRequestTypeDef",
     {
@@ -781,6 +816,7 @@ _OptionalCreateRouteRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRouteRequestRequestTypeDef",
     {
         "ClientToken": str,
+        "DefaultRoute": DefaultRouteInputTypeDef,
         "Tags": Mapping[str, str],
         "UriPathRoute": UriPathRouteInputTypeDef,
     },
